==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/5b/5baf1cbe6ddd6659bb510bce34f6ac60.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/IpLookup/AbstractRemoteDataLookup.php */
class __TwigTemplate_26c83c930a028f6e7c4794593ddc8ded extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CoreBundle\\IpLookup;

use GuzzleHttp\\Exception\\GuzzleException;

abstract class AbstractRemoteDataLookup extends AbstractLookup
{
    /**
     * Method to use when communicating with the service.
     *
     * @var string
     */
    protected \$method = 'get';

    /**
     * Get the URL to fetch data from.
     *
     * @return mixed
     */
    abstract protected function getUrl();

    /**
     * @return mixed
     */
    abstract protected function parseResponse(\$response);

    /**
     * @return array
     */
    protected function getHeaders()
    {
        return [];
    }

    /**
     * @return array
     */
    protected function getParameters()
    {
        return [];
    }

    /**
     * Fetch data from lookup service.
     */
    protected function lookup()
    {
        \$url = \$this->getUrl();

        try {
            \$response = ('post' == \$this->method) ?
                \$this->client->post(\$url, [
                    \\GuzzleHttp\\RequestOptions::BODY    => \$this->getParameters(),
                    \\GuzzleHttp\\RequestOptions::HEADERS => \$this->getHeaders(),
                    \\GuzzleHttp\\RequestOptions::TIMEOUT => 10,
                ]) :
                \$this->client->get(\$url, [
                    \\GuzzleHttp\\RequestOptions::HEADERS => \$this->getHeaders(),
                    \\GuzzleHttp\\RequestOptions::TIMEOUT => 10,
                ]);

            \$this->parseResponse(\$response->getBody());
        } catch (GuzzleException \$exception) {
            if (\$this->logger) {
                \$this->logger->warning('IP LOOKUP: '.\$exception->getMessage());
            }
        }
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/IpLookup/AbstractRemoteDataLookup.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/IpLookup/AbstractRemoteDataLookup.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/IpLookup/AbstractRemoteDataLookup.php");
    }
}

==> production-demo-20260209_093043.tar.gz: var/www/html/production-demo/var/tmp/twig/5b/5baf1cbe6ddd6659bb510bce34f6ac60.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/IpLookup/AbstractRemoteDataLookup.php */
class __TwigTemplate_26c83c930a028f6e7c4794593ddc8ded extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CoreBundle\\IpLookup;

use GuzzleHttp\\Exception\\GuzzleException;

abstract class AbstractRemoteDataLookup extends AbstractLookup
{
    /**
     * Method to use when communicating with the service.
     *
     * @var string
     */
    protected \$method = 'get';

    /**
     * Get the URL to fetch data from.
     *
     * @return mixed
     */
    abstract protected function getUrl();

    /**
     * @return mixed
     */
    abstract protected function parseResponse(\$response);

    /**
     * @return array
     */
    protected function getHeaders()
    {
        return [];
    }

    /**
     * @return array
     */
    protected function getParameters()
    {
        return [];
    }

    /**
     * Fetch data from lookup service.
     */
    protected function lookup()
    {
        \$url = \$this->getUrl();

        try {
            \$response = ('post' == \$this->method) ?
                \$this->client->post(\$url, [
                    \\GuzzleHttp\\RequestOptions::BODY    => \$this->getParameters(),
                    \\GuzzleHttp\\RequestOptions::HEADERS => \$this->getHeaders(),
                    \\GuzzleHttp\\RequestOptions::TIMEOUT => 10,
                ]) :
                \$this->client->get(\$url, [
                    \\GuzzleHttp\\RequestOptions::HEADERS => \$this->getHeaders(),
                    \\GuzzleHttp\\RequestOptions::TIMEOUT => 10,
                ]);

            \$this->parseResponse(\$response->getBody());
        } catch (GuzzleException \$exception) {
            if (\$this->logger) {
                \$this->logger->warning('IP LOOKUP: '.\$exception->getMessage());
            }
        }
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/IpLookup/AbstractRemoteDataLookup.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/IpLookup/AbstractRemoteDataLookup.php", "/var/www/html/production-demo/app/bundles/CoreBundle/IpLookup/AbstractRemoteDataLookup.php");
    }
}
